import addonHandler
import api
import globalPluginHandler
import gui
import speechDictHandler
import os
from speechDictHandler import speechDictsPath

try:
	from globalCommands import SCRCAT_SPEECH
except:
	SCRCAT_SPEECH = None

addonHandler.initTranslation()

def getAppName():
	return api.getForegroundObject().appModule.appName

def getDictFilePath(appName):
	return os.path.join(speechDictsPath, appName + '.dic')

def loadEmptyDicts():
	return dict([(f[:-4], None) for f in os.listdir(speechDictsPath) if os.path.isfile(os.path.join(speechDictsPath, f)) and f.endswith('.dic')])

def getDict(appName):
	dict = None
	if appName in dicts:
		dictFilePath = getDictFilePath(appName)
		if dicts[appName] is None:
			dict = speechDictHandler.SpeechDict()
			dict.load(dictFilePath)
			dicts[appName] = dict
		else:
			dict = dicts[appName]
	return dict

dicts = loadEmptyDicts()


class GlobalPlugin(globalPluginHandler.GlobalPlugin):
	__currentDict = None
	__currentAppName = None

	def event_foreground(self, obj, nextHandler):
		appName = getAppName()
		if self.__currentAppName is None or self.__currentAppName != appName:
			self.__currentAppName = appName
			dict = getDict(appName)
			self.__setCurrentDict(dict)
		nextHandler()

	def script_editDict(self, gesture):
		appName = getAppName()
		dict = getDict(appName)
		if dict is None:
			dictFilePath = getDictFilePath(appName)
			open(dictFilePath, 'a').close()
			dict = speechDictHandler.SpeechDict()
			dict.load(dictFilePath)
			dicts[appName] = dict
		title = _('Dictionary for %s') % appName
		gui.mainFrame._popupSettingsDialog(gui.DictionaryDialog, title, dict)
	script_editDict.category = SCRCAT_SPEECH
	script_editDict.__doc__ = _('Shows the dictionary dialog to insert entries valid only for the application in focus.')

	def __setCurrentDict(self, dict):
		if self.__currentDict is not None:
			for e in self.__currentDict: speechDictHandler.dictionaries["temp"].remove(e)
		self.__currentDict = dict
		if self.__currentDict is not None:
			speechDictHandler.dictionaries["temp"].extend(self.__currentDict)

	__gestures = {
		"kb:NVDA+Shift+p": "editDict",
}
